match_filter
============

Classes and functions for matched-filtering.

This is designed for large-scale, multi-paralleled
detection, with moderate to large numbers (hundreds to a few thousands)
of templates.

.. toctree::
   :maxdepth: 1

   core.match_filter.detection
   core.match_filter.family
   core.match_filter.helpers
   core.match_filter.matched_filter
   core.match_filter.party
   core.match_filter.template
   core.match_filter.tribe
